import 'package:flutter/material.dart';
import '/backend/schema/structs/index.dart';
import '/backend/api_requests/api_manager.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'flutter_flow/flutter_flow_util.dart';
import 'dart:convert';

class FFAppState extends ChangeNotifier {
  static FFAppState _instance = FFAppState._internal();

  factory FFAppState() {
    return _instance;
  }

  FFAppState._internal();

  static void reset() {
    _instance = FFAppState._internal();
  }

  Future initializePersistedState() async {
    prefs = await SharedPreferences.getInstance();
    _safeInit(() {
      _userCpf = prefs.getString('ff_userCpf') ?? _userCpf;
    });
    _safeInit(() {
      _userPassword = prefs.getString('ff_userPassword') ?? _userPassword;
    });
    _safeInit(() {
      _useBiometria = prefs.getBool('ff_useBiometria') ?? _useBiometria;
    });
    _safeInit(() {
      _usuarioAvantinoAPI =
          prefs.getString('ff_usuarioAvantinoAPI') ?? _usuarioAvantinoAPI;
    });
    _safeInit(() {
      _userId = prefs.getInt('ff_userId') ?? _userId;
    });
  }

  void update(VoidCallback callback) {
    callback();
    notifyListeners();
  }

  late SharedPreferences prefs;

  List<UserStruct> _users = [
    UserStruct.fromSerializableMap(jsonDecode('{\"nome\":\"Steve Perry\"}')),
    UserStruct.fromSerializableMap(jsonDecode('{\"nome\":\"Jhonny Walker\"}'))
  ];
  List<UserStruct> get users => _users;
  set users(List<UserStruct> value) {
    _users = value;
  }

  void addToUsers(UserStruct value) {
    users.add(value);
  }

  void removeFromUsers(UserStruct value) {
    users.remove(value);
  }

  void removeAtIndexFromUsers(int index) {
    users.removeAt(index);
  }

  void updateUsersAtIndex(
    int index,
    UserStruct Function(UserStruct) updateFn,
  ) {
    users[index] = updateFn(_users[index]);
  }

  void insertAtIndexInUsers(int index, UserStruct value) {
    users.insert(index, value);
  }

  List<BoletoStruct> _boletos = [
    BoletoStruct.fromSerializableMap(jsonDecode(
        '{\"id\":\"1\",\"vencimento\":\"2025-01-20\",\"valor\":\"129.9\"}')),
    BoletoStruct.fromSerializableMap(jsonDecode(
        '{\"id\":\"2\",\"vencimento\":\"2025-02-20\",\"valor\":\"129.9\"}')),
    BoletoStruct.fromSerializableMap(jsonDecode(
        '{\"id\":\"3\",\"vencimento\":\"2024-10-20\",\"valor\":\"129.9\"}')),
    BoletoStruct.fromSerializableMap(jsonDecode(
        '{\"id\":\"4\",\"vencimento\":\"2024-11-20\",\"valor\":\"129.9\",\"pago\":\"true\"}'))
  ];
  List<BoletoStruct> get boletos => _boletos;
  set boletos(List<BoletoStruct> value) {
    _boletos = value;
  }

  void addToBoletos(BoletoStruct value) {
    boletos.add(value);
  }

  void removeFromBoletos(BoletoStruct value) {
    boletos.remove(value);
  }

  void removeAtIndexFromBoletos(int index) {
    boletos.removeAt(index);
  }

  void updateBoletosAtIndex(
    int index,
    BoletoStruct Function(BoletoStruct) updateFn,
  ) {
    boletos[index] = updateFn(_boletos[index]);
  }

  void insertAtIndexInBoletos(int index, BoletoStruct value) {
    boletos.insert(index, value);
  }

  String _userCpf = '';
  String get userCpf => _userCpf;
  set userCpf(String value) {
    _userCpf = value;
    prefs.setString('ff_userCpf', value);
  }

  String _userPassword = '';
  String get userPassword => _userPassword;
  set userPassword(String value) {
    _userPassword = value;
    prefs.setString('ff_userPassword', value);
  }

  bool _useBiometria = false;
  bool get useBiometria => _useBiometria;
  set useBiometria(bool value) {
    _useBiometria = value;
    prefs.setBool('ff_useBiometria', value);
  }

  String _userToken = '';
  String get userToken => _userToken;
  set userToken(String value) {
    _userToken = value;
  }

  String _avantToken = '';
  String get avantToken => _avantToken;
  set avantToken(String value) {
    _avantToken = value;
  }

  String _usuarioAvantinoAPI = 'wiser';
  String get usuarioAvantinoAPI => _usuarioAvantinoAPI;
  set usuarioAvantinoAPI(String value) {
    _usuarioAvantinoAPI = value;
    prefs.setString('ff_usuarioAvantinoAPI', value);
  }

  String _senhaAvantinoAPI = 'cje@2024';
  String get senhaAvantinoAPI => _senhaAvantinoAPI;
  set senhaAvantinoAPI(String value) {
    _senhaAvantinoAPI = value;
  }

  String _cpfTeste = '01125607335';
  String get cpfTeste => _cpfTeste;
  set cpfTeste(String value) {
    _cpfTeste = value;
  }

  List<BeneficiarioStruct> _beneficiariosFromUser = [];
  List<BeneficiarioStruct> get beneficiariosFromUser => _beneficiariosFromUser;
  set beneficiariosFromUser(List<BeneficiarioStruct> value) {
    _beneficiariosFromUser = value;
  }

  void addToBeneficiariosFromUser(BeneficiarioStruct value) {
    beneficiariosFromUser.add(value);
  }

  void removeFromBeneficiariosFromUser(BeneficiarioStruct value) {
    beneficiariosFromUser.remove(value);
  }

  void removeAtIndexFromBeneficiariosFromUser(int index) {
    beneficiariosFromUser.removeAt(index);
  }

  void updateBeneficiariosFromUserAtIndex(
    int index,
    BeneficiarioStruct Function(BeneficiarioStruct) updateFn,
  ) {
    beneficiariosFromUser[index] = updateFn(_beneficiariosFromUser[index]);
  }

  void insertAtIndexInBeneficiariosFromUser(
      int index, BeneficiarioStruct value) {
    beneficiariosFromUser.insert(index, value);
  }

  CreatedUserStruct _createdUser = CreatedUserStruct();
  CreatedUserStruct get createdUser => _createdUser;
  set createdUser(CreatedUserStruct value) {
    _createdUser = value;
  }

  void updateCreatedUserStruct(Function(CreatedUserStruct) updateFn) {
    updateFn(_createdUser);
  }

  int _userId = 0;
  int get userId => _userId;
  set userId(int value) {
    _userId = value;
    prefs.setInt('ff_userId', value);
  }

  String _idselecionado = '';
  String get idselecionado => _idselecionado;
  set idselecionado(String value) {
    _idselecionado = value;
  }

  bool _ciente = false;
  bool get ciente => _ciente;
  set ciente(bool value) {
    _ciente = value;
  }

  bool _cientealteracao = false;
  bool get cientealteracao => _cientealteracao;
  set cientealteracao(bool value) {
    _cientealteracao = value;
  }

  dynamic _dadosatuaistemp;
  dynamic get dadosatuaistemp => _dadosatuaistemp;
  set dadosatuaistemp(dynamic value) {
    _dadosatuaistemp = value;
  }

  List<String> _listaarquivosupload = [];
  List<String> get listaarquivosupload => _listaarquivosupload;
  set listaarquivosupload(List<String> value) {
    _listaarquivosupload = value;
  }

  void addToListaarquivosupload(String value) {
    listaarquivosupload.add(value);
  }

  void removeFromListaarquivosupload(String value) {
    listaarquivosupload.remove(value);
  }

  void removeAtIndexFromListaarquivosupload(int index) {
    listaarquivosupload.removeAt(index);
  }

  void updateListaarquivosuploadAtIndex(
    int index,
    String Function(String) updateFn,
  ) {
    listaarquivosupload[index] = updateFn(_listaarquivosupload[index]);
  }

  void insertAtIndexInListaarquivosupload(int index, String value) {
    listaarquivosupload.insert(index, value);
  }

  bool _solicitarconfirmado = false;
  bool get solicitarconfirmado => _solicitarconfirmado;
  set solicitarconfirmado(bool value) {
    _solicitarconfirmado = value;
  }

  int _idrepresentante = 0;
  int get idrepresentante => _idrepresentante;
  set idrepresentante(int value) {
    _idrepresentante = value;
  }

  String _parentesco = '';
  String get parentesco => _parentesco;
  set parentesco(String value) {
    _parentesco = value;
  }

  int _idcontratorepresentante = 0;
  int get idcontratorepresentante => _idcontratorepresentante;
  set idcontratorepresentante(int value) {
    _idcontratorepresentante = value;
  }

  bool _checkoutsolicitacao = false;
  bool get checkoutsolicitacao => _checkoutsolicitacao;
  set checkoutsolicitacao(bool value) {
    _checkoutsolicitacao = value;
  }

  dynamic _novosdadostemp = jsonDecode('null');
  dynamic get novosdadostemp => _novosdadostemp;
  set novosdadostemp(dynamic value) {
    _novosdadostemp = value;
  }

  dynamic _solicitacaoalterarepresentante;
  dynamic get solicitacaoalterarepresentante => _solicitacaoalterarepresentante;
  set solicitacaoalterarepresentante(dynamic value) {
    _solicitacaoalterarepresentante = value;
  }

  dynamic _arquivosupload;
  dynamic get arquivosupload => _arquivosupload;
  set arquivosupload(dynamic value) {
    _arquivosupload = value;
  }

  String _vinculo = '';
  String get vinculo => _vinculo;
  set vinculo(String value) {
    _vinculo = value;
  }

  dynamic _deps;
  dynamic get deps => _deps;
  set deps(dynamic value) {
    _deps = value;
  }

  bool _latitudelongitudeexiste = false;
  bool get latitudelongitudeexiste => _latitudelongitudeexiste;
  set latitudelongitudeexiste(bool value) {
    _latitudelongitudeexiste = value;
  }

  dynamic _dadosatuaistempdependentes;
  dynamic get dadosatuaistempdependentes => _dadosatuaistempdependentes;
  set dadosatuaistempdependentes(dynamic value) {
    _dadosatuaistempdependentes = value;
  }

  dynamic _novosdadostempdependentes;
  dynamic get novosdadostempdependentes => _novosdadostempdependentes;
  set novosdadostempdependentes(dynamic value) {
    _novosdadostempdependentes = value;
  }

  dynamic _solicitacaoalteradependente;
  dynamic get solicitacaoalteradependente => _solicitacaoalteradependente;
  set solicitacaoalteradependente(dynamic value) {
    _solicitacaoalteradependente = value;
  }

  bool _adicionardependentehome = false;
  bool get adicionardependentehome => _adicionardependentehome;
  set adicionardependentehome(bool value) {
    _adicionardependentehome = value;
  }

  bool _contratoexiste = false;
  bool get contratoexiste => _contratoexiste;
  set contratoexiste(bool value) {
    _contratoexiste = value;
  }

  bool _filtroOnOff = false;
  bool get filtroOnOff => _filtroOnOff;
  set filtroOnOff(bool value) {
    _filtroOnOff = value;
  }

  int _statusselecionado = 0;
  int get statusselecionado => _statusselecionado;
  set statusselecionado(int value) {
    _statusselecionado = value;
  }

  int _tiposelecionado = 0;
  int get tiposelecionado => _tiposelecionado;
  set tiposelecionado(int value) {
    _tiposelecionado = value;
  }

  int _Valor1 = 0;
  int get Valor1 => _Valor1;
  set Valor1(int value) {
    _Valor1 = value;
  }

  String _Valor2 = '';
  String get Valor2 => _Valor2;
  set Valor2(String value) {
    _Valor2 = value;
  }

  String _Valor3 = '';
  String get Valor3 => _Valor3;
  set Valor3(String value) {
    _Valor3 = value;
  }

  dynamic _solicitacaoexcluirdependente;
  dynamic get solicitacaoexcluirdependente => _solicitacaoexcluirdependente;
  set solicitacaoexcluirdependente(dynamic value) {
    _solicitacaoexcluirdependente = value;
  }

  bool _statusdasolicitacaorecusada = false;
  bool get statusdasolicitacaorecusada => _statusdasolicitacaorecusada;
  set statusdasolicitacaorecusada(bool value) {
    _statusdasolicitacaorecusada = value;
  }

  bool _planonovo = false;
  bool get planonovo => _planonovo;
  set planonovo(bool value) {
    _planonovo = value;
  }

  dynamic _representanteJson;
  dynamic get representanteJson => _representanteJson;
  set representanteJson(dynamic value) {
    _representanteJson = value;
  }

  List<NotificacaoStruct> _notificacoesListState = [];
  List<NotificacaoStruct> get notificacoesListState => _notificacoesListState;
  set notificacoesListState(List<NotificacaoStruct> value) {
    _notificacoesListState = value;
  }

  void addToNotificacoesListState(NotificacaoStruct value) {
    notificacoesListState.add(value);
  }

  void removeFromNotificacoesListState(NotificacaoStruct value) {
    notificacoesListState.remove(value);
  }

  void removeAtIndexFromNotificacoesListState(int index) {
    notificacoesListState.removeAt(index);
  }

  void updateNotificacoesListStateAtIndex(
    int index,
    NotificacaoStruct Function(NotificacaoStruct) updateFn,
  ) {
    notificacoesListState[index] = updateFn(_notificacoesListState[index]);
  }

  void insertAtIndexInNotificacoesListState(
      int index, NotificacaoStruct value) {
    notificacoesListState.insert(index, value);
  }

  int _qtdNotificacoesNaoLidas = 0;
  int get qtdNotificacoesNaoLidas => _qtdNotificacoesNaoLidas;
  set qtdNotificacoesNaoLidas(int value) {
    _qtdNotificacoesNaoLidas = value;
  }

  bool _pixselecionado = false;
  bool get pixselecionado => _pixselecionado;
  set pixselecionado(bool value) {
    _pixselecionado = value;
  }

  bool _negociardividaselecionado = false;
  bool get negociardividaselecionado => _negociardividaselecionado;
  set negociardividaselecionado(bool value) {
    _negociardividaselecionado = value;
  }

  String _tokenv2 = '';
  String get tokenv2 => _tokenv2;
  set tokenv2(String value) {
    _tokenv2 = value;
  }

  String _urlpdf = '';
  String get urlpdf => _urlpdf;
  set urlpdf(String value) {
    _urlpdf = value;
  }

  bool _composicaoselecionado = false;
  bool get composicaoselecionado => _composicaoselecionado;
  set composicaoselecionado(bool value) {
    _composicaoselecionado = value;
  }

  bool _mesesselecionado = false;
  bool get mesesselecionado => _mesesselecionado;
  set mesesselecionado(bool value) {
    _mesesselecionado = value;
  }

  List<String> _Valor4 = [];
  List<String> get Valor4 => _Valor4;
  set Valor4(List<String> value) {
    _Valor4 = value;
  }

  void addToValor4(String value) {
    Valor4.add(value);
  }

  void removeFromValor4(String value) {
    Valor4.remove(value);
  }

  void removeAtIndexFromValor4(int index) {
    Valor4.removeAt(index);
  }

  void updateValor4AtIndex(
    int index,
    String Function(String) updateFn,
  ) {
    Valor4[index] = updateFn(_Valor4[index]);
  }

  void insertAtIndexInValor4(int index, String value) {
    Valor4.insert(index, value);
  }

  List<int> _Valor5 = [];
  List<int> get Valor5 => _Valor5;
  set Valor5(List<int> value) {
    _Valor5 = value;
  }

  void addToValor5(int value) {
    Valor5.add(value);
  }

  void removeFromValor5(int value) {
    Valor5.remove(value);
  }

  void removeAtIndexFromValor5(int index) {
    Valor5.removeAt(index);
  }

  void updateValor5AtIndex(
    int index,
    int Function(int) updateFn,
  ) {
    Valor5[index] = updateFn(_Valor5[index]);
  }

  void insertAtIndexInValor5(int index, int value) {
    Valor5.insert(index, value);
  }

  String _cpfpermanente = '';
  String get cpfpermanente => _cpfpermanente;
  set cpfpermanente(String value) {
    _cpfpermanente = value;
  }

  String _nomerepresentantepermanente = '';
  String get nomerepresentantepermanente => _nomerepresentantepermanente;
  set nomerepresentantepermanente(String value) {
    _nomerepresentantepermanente = value;
  }

  String _imagemavatar = '';
  String get imagemavatar => _imagemavatar;
  set imagemavatar(String value) {
    _imagemavatar = value;
  }

  String _urlavatarusuario = '';
  String get urlavatarusuario => _urlavatarusuario;
  set urlavatarusuario(String value) {
    _urlavatarusuario = value;
  }

  String _urlavatarusuariocompleta = '';
  String get urlavatarusuariocompleta => _urlavatarusuariocompleta;
  set urlavatarusuariocompleta(String value) {
    _urlavatarusuariocompleta = value;
  }

  String _fileName = '';
  String get fileName => _fileName;
  set fileName(String value) {
    _fileName = value;
  }

  List<String> _fileNames = [];
  List<String> get fileNames => _fileNames;
  set fileNames(List<String> value) {
    _fileNames = value;
  }

  void addToFileNames(String value) {
    fileNames.add(value);
  }

  void removeFromFileNames(String value) {
    fileNames.remove(value);
  }

  void removeAtIndexFromFileNames(int index) {
    fileNames.removeAt(index);
  }

  void updateFileNamesAtIndex(
    int index,
    String Function(String) updateFn,
  ) {
    fileNames[index] = updateFn(_fileNames[index]);
  }

  void insertAtIndexInFileNames(int index, String value) {
    fileNames.insert(index, value);
  }
}

void _safeInit(Function() initializeField) {
  try {
    initializeField();
  } catch (_) {}
}

Future _safeInitAsync(Function() initializeField) async {
  try {
    await initializeField();
  } catch (_) {}
}
