import 'dart:convert';
import 'dart:typed_data';
import '../schema/structs/index.dart';

import 'package:flutter/foundation.dart';

import '/flutter_flow/flutter_flow_util.dart';
import 'api_manager.dart';

export 'api_manager.dart' show ApiCallResponse;

const _kPrivateApiFunctionName = 'ffPrivateApiCall';

/// Start Grupo API Avantino I Group Code

class GrupoAPIAvantinoIGroup {
  static String getBaseUrl({
    String? token = '',
    String? dominio = 'cje',
  }) =>
      'https://avantino.pbr.digital/cje/api/avantino/';
  static Map<String, String> headers = {
    'Accept': '*/*',
    'Connection': 'keep-alive',
    'Content-Type': 'application/json',
    'Authorization': '[token]',
  };
  static ConsultaPlanosBeneficiarioPorCPFEDataNascimentoCall
      consultaPlanosBeneficiarioPorCPFEDataNascimentoCall =
      ConsultaPlanosBeneficiarioPorCPFEDataNascimentoCall();
  static ContratoIDResumoBeneficiarioNaNCall
      contratoIDResumoBeneficiarioNaNCall =
      ContratoIDResumoBeneficiarioNaNCall();
  static ContratoIDCompletoBeneficiarioCall contratoIDCompletoBeneficiarioCall =
      ContratoIDCompletoBeneficiarioCall();
  static ContratoIDCompletoBeneficiarioResumidoCall
      contratoIDCompletoBeneficiarioResumidoCall =
      ContratoIDCompletoBeneficiarioResumidoCall();
  static BeneficiariosIDContratoCall beneficiariosIDContratoCall =
      BeneficiariosIDContratoCall();
  static ConsultaPlanosBeneficiarioPorCPFCall
      consultaPlanosBeneficiarioPorCPFCall =
      ConsultaPlanosBeneficiarioPorCPFCall();
  static FinanceiroFormaPagamentoCall financeiroFormaPagamentoCall =
      FinanceiroFormaPagamentoCall();
  static FinanceiroAdquirentesCall financeiroAdquirentesCall =
      FinanceiroAdquirentesCall();
  static FinanceiroBandeirasCall financeiroBandeirasCall =
      FinanceiroBandeirasCall();
  static FinanceiroContasBoletoCall financeiroContasBoletoCall =
      FinanceiroContasBoletoCall();
  static FinanceiroUnidadeColetaCall financeiroUnidadeColetaCall =
      FinanceiroUnidadeColetaCall();
  static FinanceiroConsultasParametrizadasCall
      financeiroConsultasParametrizadasCall =
      FinanceiroConsultasParametrizadasCall();
  static PedidoAlteracaoContratoCall pedidoAlteracaoContratoCall =
      PedidoAlteracaoContratoCall();
  static LoteIDContratosTitularCall loteIDContratosTitularCall =
      LoteIDContratosTitularCall();
  static LoteBoletosCall loteBoletosCall = LoteBoletosCall();
  static FaturasByContratoCall faturasByContratoCall = FaturasByContratoCall();
}

class ConsultaPlanosBeneficiarioPorCPFEDataNascimentoCall {
  Future<ApiCallResponse> call({
    String? cpf = '',
    String? dtNascimento = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Consulta Planos Beneficiario Por CPF e Data Nascimento',
      apiUrl: '${baseUrl}beneficiarios/consulta',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {
        'cpf': cpf,
        'dtNascimento': dtNascimento,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<BeneficiarioStruct>? result(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => BeneficiarioStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
  List<int>? idPessoa(dynamic response) => (getJsonField(
        response,
        r'''$[:].idPessoa''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
  List<int>? idContrato(dynamic response) => (getJsonField(
        response,
        r'''$[:].idContrato''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
  List<String>? nmPessoa(dynamic response) => (getJsonField(
        response,
        r'''$[:].nmPessoa''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? cdCPF(dynamic response) => (getJsonField(
        response,
        r'''$[:].cdCpf''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
}

class ContratoIDResumoBeneficiarioNaNCall {
  Future<ApiCallResponse> call({
    String? idContrato = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Contrato ID Resumo Beneficiario NaN',
      apiUrl: '${baseUrl}contratos',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {
        'idContrato': idContrato,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<ContratoStruct>? results(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => ContratoStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
  int? idContrato(dynamic response) => castToType<int>(getJsonField(
        response,
        r'''$[:].idContrato''',
      ));
  String? logradouro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmLogradouroCompleto''',
      ));
  String? numeroLogradouro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nrLogradouro''',
      ));
  String? bairro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmBairro''',
      ));
  String? cidade(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmCidade''',
      ));
  String? estado(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].sgEstado''',
      ));
  String? complemento(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dsComplemento''',
      ));
  String? cep(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdCep''',
      ));
}

class ContratoIDCompletoBeneficiarioCall {
  Future<ApiCallResponse> call({
    String? idCont = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Contrato ID Completo Beneficiario',
      apiUrl: '${baseUrl}contratos/${idCont}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<ContratoStruct>? results(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => ContratoStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
  String? nmPessoa(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmPessoa''',
      ));
  dynamic? dsQuadra(dynamic response) => getJsonField(
        response,
        r'''$[:].dsQuadra''',
      );
  List<String>? dsLote(dynamic response) => (getJsonField(
        response,
        r'''$[:].dsLote''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  String? telMovel(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdTelMovel''',
      ));
  String? telResidencia(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdTelResidencial''',
      ));
  String? logradouro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmLogradouroCompleto''',
      ));
  String? numero(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nrLogradouro''',
      ));
  String? bairro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmBairro''',
      ));
  String? cidade(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmCidade''',
      ));
  String? estado(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].sgEstado''',
      ));
  String? cep(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdCep''',
      ));
  String? complemento(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dsComplemento''',
      ));
  String? quadra(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dsQuadra''',
      ));
  String? lote(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dsLote''',
      ));
}

class ContratoIDCompletoBeneficiarioResumidoCall {
  Future<ApiCallResponse> call({
    String? idCont = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Contrato ID Completo Beneficiario Resumido',
      apiUrl: '${baseUrl}contratos/${idCont}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  dynamic? dsQuadra(dynamic response) => getJsonField(
        response,
        r'''$[:].dsQuadra''',
      );
  List<String>? dsLote(dynamic response) => (getJsonField(
        response,
        r'''$[:].dsLote''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  String? telMovel(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdTelMovel''',
      ));
  String? telResidencia(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdTelResidencial''',
      ));
  String? logradouro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmLogradouroCompleto''',
      ));
  String? numero(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nrLogradouro''',
      ));
  String? bairro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmBairro''',
      ));
  String? cidade(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmCidade''',
      ));
  String? estado(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].sgEstado''',
      ));
  String? cep(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdCep''',
      ));
  String? complemento(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dsComplemento''',
      ));
  String? quadra(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dsQuadra''',
      ));
  String? lote(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dsLote''',
      ));
}

class BeneficiariosIDContratoCall {
  Future<ApiCallResponse> call({
    String? idCont = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Beneficiarios ID Contrato',
      apiUrl: '${baseUrl}beneficiarios/${idCont}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<ContratoStruct>? results(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => ContratoStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
  List<String>? nmPessoa(dynamic response) => (getJsonField(
        response,
        r'''$[:].nmPessoa''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<int>? idContrato(dynamic response) => (getJsonField(
        response,
        r'''$[:].idContrato''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
  List<String>? nmGrau(dynamic response) => (getJsonField(
        response,
        r'''$[:].nmGrau''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? nmVinculo(dynamic response) => (getJsonField(
        response,
        r'''$[:].nmVinculo''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? cdCPF(dynamic response) => (getJsonField(
        response,
        r'''$[:].cdCPF''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? dtNascimento(dynamic response) => (getJsonField(
        response,
        r'''$[:].dtNascimento''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? dtCarencia(dynamic response) => (getJsonField(
        response,
        r'''$[:].dtCarencia''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? dtInclusao(dynamic response) => (getJsonField(
        response,
        r'''$[:].dtInclusao''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<int>? idBeneficiado(dynamic response) => (getJsonField(
        response,
        r'''$[:].idBeneficiado''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
  List<int>? idPessoa(dynamic response) => (getJsonField(
        response,
        r'''$[:].idPessoa''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
}

class ConsultaPlanosBeneficiarioPorCPFCall {
  Future<ApiCallResponse> call({
    String? cdCpf = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Consulta Planos Beneficiario Por CPF',
      apiUrl: '${baseUrl}contratos',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {
        'cdCpf': cdCpf,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<ContratoStruct>? results(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => ContratoStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
}

class FinanceiroFormaPagamentoCall {
  Future<ApiCallResponse> call({
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Financeiro Forma Pagamento',
      apiUrl: '${baseUrl}formapagamento',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class FinanceiroAdquirentesCall {
  Future<ApiCallResponse> call({
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Financeiro Adquirentes',
      apiUrl: '${baseUrl}adquirentes',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class FinanceiroBandeirasCall {
  Future<ApiCallResponse> call({
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Financeiro Bandeiras',
      apiUrl: '${baseUrl}/bandeiras',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class FinanceiroContasBoletoCall {
  Future<ApiCallResponse> call({
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Financeiro Contas Boleto',
      apiUrl: '${baseUrl}/contasboleto',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class FinanceiroUnidadeColetaCall {
  Future<ApiCallResponse> call({
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Financeiro Unidade Coleta',
      apiUrl: '${baseUrl}/unidadecoleta',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class FinanceiroConsultasParametrizadasCall {
  Future<ApiCallResponse> call({
    String? idContrato = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Financeiro Consultas Parametrizadas',
      apiUrl: '${baseUrl}consultasparametrizadas/29',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {
        'idContrato': idContrato,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  int? idAssentado(dynamic response) => castToType<int>(getJsonField(
        response,
        r'''$[:].idAssentamento''',
      ));
  String? nmTipoLoculo(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmTipoLoculo''',
      ));
  String? cdLoculo(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdLoculo''',
      ));
  String? nmAssentado(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].nmAssentado''',
      ));
  String? cdEstadoCivil(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdEstadoCivil''',
      ));
  String? dtSepultamento(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dtSepultamento''',
      ));
  String? hrSepultamento(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].hrSepultamento''',
      ));
  String? dtNascimento(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dtNascimento''',
      ));
  String? sexo(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].sexo''',
      ));
  String? cdReligiao(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].cdReligiao''',
      ));
  String? dtObito(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].dtObito''',
      ));
  String? hrObito(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$[:].hrObito''',
      ));
  int? idContrato(dynamic response) => castToType<int>(getJsonField(
        response,
        r'''$[:].idContrato''',
      ));
  List<JazigosDataTypeStruct>? result(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => JazigosDataTypeStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
}

class PedidoAlteracaoContratoCall {
  Future<ApiCallResponse> call({
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    final ffApiRequestBody = '''
{
  "idContrato": 0,
  "cdTelResidencial": "",
  "cdTelComercial": "",
  "cdTelMovel": "",
  "vlLatitude": "",
  "vlLongitude": "",
  "ddCobranca": 0,
  "nmEndereco": "",
  "nmBairro": "",
  "nmCidade": "",
  "nmLocalPagamento": ""
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'Pedido Alteracao Contrato',
      apiUrl: '${baseUrl}/pedidoalteracaocontrato',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  dynamic? error(dynamic response) => getJsonField(
        response,
        r'''$.error''',
      );
}

class LoteIDContratosTitularCall {
  Future<ApiCallResponse> call({
    String? idContrato = '',
    int? p,
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Lote ID Contratos Titular',
      apiUrl: '${baseUrl}/lote/contratos',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {
        'idContrato': idContrato,
        'p': p,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class LoteBoletosCall {
  Future<ApiCallResponse> call({
    String? dtInicio = '',
    String? dtFim = '',
    int? p,
    String? anyItem = '',
    String? query = '',
    int? itemsPerPage,
    String? idContrato = '',
    String? idBoleto = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'Lote Boletos',
      apiUrl: '${baseUrl}/lote/boletos',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {
        'dtInicio': dtInicio,
        'dtFim': dtFim,
        'p': p,
        'anyItem': anyItem,
        'query': query,
        'itemsPerPage': itemsPerPage,
        'idBoleto': idBoleto,
        'idContrato': idContrato,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class FaturasByContratoCall {
  Future<ApiCallResponse> call({
    int? idContrato,
    String? flPago = '',
    String? token = '',
    String? dominio = 'cje',
  }) async {
    final baseUrl = GrupoAPIAvantinoIGroup.getBaseUrl(
      token: token,
      dominio: dominio,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'FaturasByContrato',
      apiUrl: '${baseUrl}faturas/${idContrato}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/json',
        'Authorization': '${token}',
      },
      params: {
        'flPago': flPago,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<FaturaStruct>? resukt(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => FaturaStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
  List<String>? cdLinhaDigitavel(dynamic response) => (getJsonField(
        response,
        r'''$[:].cdLinhaDigitavel''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? idBoleto(dynamic response) => (getJsonField(
        response,
        r'''$[:].idBoleto''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<int>? idContrato(dynamic response) => (getJsonField(
        response,
        r'''$[:].idContrato''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
}

/// End Grupo API Avantino I Group Code

/// Start Grupo Wiser API Usuarios HML Group Code

class GrupoWiserAPIUsuariosHMLGroup {
  static String getBaseUrl() => 'http://194.163.175.62:8888/usuarios';
  static Map<String, String> headers = {
    'Accept': '*/*',
    'Content-Type': 'application/json',
  };
  static WiserAPILoginHMLCall wiserAPILoginHMLCall = WiserAPILoginHMLCall();
}

class WiserAPILoginHMLCall {
  Future<ApiCallResponse> call({
    String? cpf = '',
    String? senha = '',
  }) async {
    final baseUrl = GrupoWiserAPIUsuariosHMLGroup.getBaseUrl();

    final ffApiRequestBody = '''
{
  "cpf": "${escapeStringForJson(cpf)}",
  "senha": "${escapeStringForJson(senha)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'Wiser API  Login HML',
      apiUrl: '${baseUrl}/login/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  UserDataStruct? result(dynamic response) =>
      UserDataStruct.maybeFromMap(getJsonField(
        response,
        r'''$''',
      ));
}

/// End Grupo Wiser API Usuarios HML Group Code

/// Start Servidor Jardim Usuarios Group Code

class ServidorJardimUsuariosGroup {
  static String getBaseUrl({
    String? token = '',
  }) =>
      'http://194.163.175.62:8888';
  static Map<String, String> headers = {
    'Accept': '*/*',
    'Content-Type': 'application/json',
    'Authorization': 'Bearer [token]',
  };
  static UserLoginCall userLoginCall = UserLoginCall();
  static CreateUserCall createUserCall = CreateUserCall();
  static VerifyCodeCall verifyCodeCall = VerifyCodeCall();
  static GetRepresentantesCall getRepresentantesCall = GetRepresentantesCall();
  static ResetPasswordCall resetPasswordCall = ResetPasswordCall();
  static ReenviarTokenCall reenviarTokenCall = ReenviarTokenCall();
  static UpdatePasswordCall updatePasswordCall = UpdatePasswordCall();
  static RecoveryPasswordCall recoveryPasswordCall = RecoveryPasswordCall();
  static AddPasswordToNewUserCall addPasswordToNewUserCall =
      AddPasswordToNewUserCall();
  static AddRepresentanteCall addRepresentanteCall = AddRepresentanteCall();
  static GetSolicitacaoImageCall getSolicitacaoImageCall =
      GetSolicitacaoImageCall();
  static SolicitacaoAlteraRepresentanteCall solicitacaoAlteraRepresentanteCall =
      SolicitacaoAlteraRepresentanteCall();
  static SolicitacaoAlteraSolicitacaoCall solicitacaoAlteraSolicitacaoCall =
      SolicitacaoAlteraSolicitacaoCall();
  static SolicitacaoAlteraDependenteCall solicitacaoAlteraDependenteCall =
      SolicitacaoAlteraDependenteCall();
  static SolicitacaoIncluirDependenteCall solicitacaoIncluirDependenteCall =
      SolicitacaoIncluirDependenteCall();
  static AvatarUsuarioCall avatarUsuarioCall = AvatarUsuarioCall();
  static ObterAvatarUsuarioCall obterAvatarUsuarioCall =
      ObterAvatarUsuarioCall();
  static SolicitacaoExcluirDependenteCall solicitacaoExcluirDependenteCall =
      SolicitacaoExcluirDependenteCall();
  static SolicitacaoHistoricoIDCall solicitacaoHistoricoIDCall =
      SolicitacaoHistoricoIDCall();
  static GetNotificacoesUsuarioCall getNotificacoesUsuarioCall =
      GetNotificacoesUsuarioCall();
  static UpdateNotificacoesUsuarioCall updateNotificacoesUsuarioCall =
      UpdateNotificacoesUsuarioCall();
}

class UserLoginCall {
  Future<ApiCallResponse> call({
    String? cpf = '',
    String? senha = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "cpf": "${escapeStringForJson(cpf)}",
  "senha": "${escapeStringForJson(senha)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'UserLogin',
      apiUrl: '${baseUrl}/usuarios/login/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? token(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.access_token''',
      ));
}

class CreateUserCall {
  Future<ApiCallResponse> call({
    String? nomeCompleto = '',
    String? cpf = '',
    String? whatsapp = '',
    String? email = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "nome_completo": "${escapeStringForJson(nomeCompleto)}",
  "cpf": "${escapeStringForJson(cpf)}",
  "whatsapp": "${escapeStringForJson(whatsapp)}",
  "email": "${escapeStringForJson(email)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'CreateUser',
      apiUrl: '${baseUrl}/usuarios/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? detail(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
  CreatedUserStruct? rsult(dynamic response) =>
      CreatedUserStruct.maybeFromMap(getJsonField(
        response,
        r'''$''',
      ));
}

class VerifyCodeCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? codigo = '',
    String? tipo = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_id": ${usuarioId},
  "codigo": "${escapeStringForJson(codigo)}",
  "tipo": "${escapeStringForJson(tipo)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'verifyCode',
      apiUrl: '${baseUrl}/usuarios/verificar/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? mensagem(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.message''',
      ));
  String? erro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
}

class GetRepresentantesCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'getRepresentantes',
      apiUrl: '${baseUrl}/usuarios/${usuarioId}/representantes/',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<RepresentanteStruct>? result(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => RepresentanteStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
}

class ResetPasswordCall {
  Future<ApiCallResponse> call({
    String? email = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{"email":"${escapeStringForJson(email)}"}''';
    return ApiManager.instance.makeApiCall(
      callName: 'resetPassword',
      apiUrl: '${baseUrl}/usuarios/resetar_senha/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? mensagem(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.message''',
      ));
}

class ReenviarTokenCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? tipo = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_id": "${usuarioId}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'reenviarToken',
      apiUrl: '${baseUrl}/usuarios/reenviar_token/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class UpdatePasswordCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? codigo = '',
    String? novaSenha = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_id": ${usuarioId}
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'updatePassword',
      apiUrl: '${baseUrl}/usuarios/atualizar_senha/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class RecoveryPasswordCall {
  Future<ApiCallResponse> call({
    String? email = '',
    String? cpf = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "cpf": "${escapeStringForJson(cpf)}",
  "email": "${escapeStringForJson(email)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'recoveryPassword',
      apiUrl: '${baseUrl}/usuarios/recuperar_senha/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  UserDataStruct? result(dynamic response) =>
      UserDataStruct.maybeFromMap(getJsonField(
        response,
        r'''$''',
      ));
  String? error(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
}

class AddPasswordToNewUserCall {
  Future<ApiCallResponse> call({
    String? usuarioCpf = '',
    String? senha = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_cpf": "${escapeStringForJson(usuarioCpf)}",
  "senha": "${escapeStringForJson(senha)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'addPasswordToNewUser',
      apiUrl: '${baseUrl}/usuarios/${usuarioCpf}/senha/',
      callType: ApiCallType.PATCH,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? detail(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
}

class AddRepresentanteCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? cpf = '',
    String? nome = '',
    String? dataNascimento = '',
    String? parentesco = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "nome": "${escapeStringForJson(nome)}",
  "cpf": "${escapeStringForJson(cpf)}",
  "parentesco": "${escapeStringForJson(parentesco)}",
  "data_nascimento": "${escapeStringForJson(dataNascimento)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'addRepresentante',
      apiUrl: '${baseUrl}/usuarios/${usuarioId}/representantes/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  int? idRepresentante(dynamic response) => castToType<int>(getJsonField(
        response,
        r'''$.id''',
      ));
  String? nome(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.nome''',
      ));
  String? cpf(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.cpf''',
      ));
  String? parentesco(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.parentesco''',
      ));
  String? datanascimento(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.data_nascimento''',
      ));
  int? usuarioid(dynamic response) => castToType<int>(getJsonField(
        response,
        r'''$.usuario_id''',
      ));
}

class GetSolicitacaoImageCall {
  Future<ApiCallResponse> call({
    String? filename = '',
    int? solicitacaoId,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'getSolicitacaoImage',
      apiUrl: '${baseUrl}/files/${solicitacaoId}/${filename}/${token}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class SolicitacaoAlteraRepresentanteCall {
  Future<ApiCallResponse> call({
    dynamic? dadosconfJson,
    dynamic? dadosatuaisJson,
    dynamic? dadosnovosJson,
    List<FFUploadedFile>? filesList,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );
    final files = filesList ?? [];
    final dadosconf = _serializeJson(dadosconfJson);
    final dadosatuais = _serializeJson(dadosatuaisJson);
    final dadosnovos = _serializeJson(dadosnovosJson);

    return ApiManager.instance.makeApiCall(
      callName: 'SolicitacaoAlteraRepresentante',
      apiUrl: '${baseUrl}/solicitacoes',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {
        'solicitacao': dadosconf,
        'json_antes': dadosatuais,
        'json_depois': dadosnovos,
        'files': files,
      },
      bodyType: BodyType.MULTIPART,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class SolicitacaoAlteraSolicitacaoCall {
  Future<ApiCallResponse> call({
    dynamic? dadosconfJson,
    dynamic? dadosatuaisJson,
    dynamic? dadosnovosJson,
    List<FFUploadedFile>? filesList,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );
    final files = filesList ?? [];
    final dadosconf = _serializeJson(dadosconfJson);
    final dadosatuais = _serializeJson(dadosatuaisJson);
    final dadosnovos = _serializeJson(dadosnovosJson);

    return ApiManager.instance.makeApiCall(
      callName: 'SolicitacaoAlteraSolicitacao',
      apiUrl: '${baseUrl}/solicitacoes',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {
        'solicitacao': dadosconf,
        'json_antes': dadosatuais,
        'json_depois': dadosnovos,
        'files': files,
      },
      bodyType: BodyType.MULTIPART,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class SolicitacaoAlteraDependenteCall {
  Future<ApiCallResponse> call({
    dynamic? dadosconfJson,
    dynamic? dadosatuaisJson,
    dynamic? dadosnovosJson,
    List<FFUploadedFile>? filesList,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );
    final files = filesList ?? [];
    final dadosconf = _serializeJson(dadosconfJson);
    final dadosatuais = _serializeJson(dadosatuaisJson);
    final dadosnovos = _serializeJson(dadosnovosJson);

    return ApiManager.instance.makeApiCall(
      callName: 'SolicitacaoAlteraDependente',
      apiUrl: '${baseUrl}/solicitacoes',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {
        'solicitacao': dadosconf,
        'json_antes': dadosatuais,
        'json_depois': dadosnovos,
        'files': files,
      },
      bodyType: BodyType.MULTIPART,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class SolicitacaoIncluirDependenteCall {
  Future<ApiCallResponse> call({
    dynamic? dadosconfJson,
    dynamic? dadosatuaisJson,
    dynamic? dadosnovosJson,
    List<FFUploadedFile>? filesList,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );
    final files = filesList ?? [];
    final dadosconf = _serializeJson(dadosconfJson);
    final dadosatuais = _serializeJson(dadosatuaisJson);
    final dadosnovos = _serializeJson(dadosnovosJson);

    return ApiManager.instance.makeApiCall(
      callName: 'SolicitacaoIncluirDependente',
      apiUrl: '${baseUrl}/solicitacoes',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {
        'solicitacao': dadosconf,
        'json_antes': dadosatuais,
        'json_depois': dadosnovos,
        'files': files,
      },
      bodyType: BodyType.MULTIPART,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class AvatarUsuarioCall {
  Future<ApiCallResponse> call({
    FFUploadedFile? file,
    int? usuarioId,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'AvatarUsuario',
      apiUrl: '${baseUrl}/usuarios/${usuarioId}/avatar/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {
        'file': file,
      },
      bodyType: BodyType.MULTIPART,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class ObterAvatarUsuarioCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'ObterAvatarUsuario',
      apiUrl: '${baseUrl}/usuarios/${usuarioId}/avatar/',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? avatarurl(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.avatar_url''',
      ));
}

class SolicitacaoExcluirDependenteCall {
  Future<ApiCallResponse> call({
    dynamic? dadosconfJson,
    dynamic? dadosatuaisJson,
    dynamic? dadosnovosJson,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    final dadosconf = _serializeJson(dadosconfJson);
    final dadosatuais = _serializeJson(dadosatuaisJson);
    final dadosnovos = _serializeJson(dadosnovosJson);

    return ApiManager.instance.makeApiCall(
      callName: 'SolicitacaoExcluirDependente',
      apiUrl: '${baseUrl}/solicitacoes',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {
        'solicitacao': dadosconf,
        'json_antes': dadosatuais,
        'json_depois': dadosnovos,
      },
      bodyType: BodyType.MULTIPART,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class SolicitacaoHistoricoIDCall {
  Future<ApiCallResponse> call({
    String? id = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'SolicitacaoHistoricoID',
      apiUrl: '${baseUrl}/solicitacoes/${id}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<String>? categoria(dynamic response) => (getJsonField(
        response,
        r'''$[:].categoria''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<int>? usuarioid(dynamic response) => (getJsonField(
        response,
        r'''$[:].usuario_id''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
  List<String>? datahoracriacao(dynamic response) => (getJsonField(
        response,
        r'''$[:].data_hora_criacao''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List? responsavelid(dynamic response) => getJsonField(
        response,
        r'''$[:].responsavel_id''',
        true,
      ) as List?;
  List? observacao(dynamic response) => getJsonField(
        response,
        r'''$[:].observacao''',
        true,
      ) as List?;
  List<int>? tipoid(dynamic response) => (getJsonField(
        response,
        r'''$[:].tipo_id''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<int>(x))
          .withoutNulls
          .toList();
  List<String>? nomeatendente(dynamic response) => (getJsonField(
        response,
        r'''$[:].responsavel.name''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
  List<String>? avataratendente(dynamic response) => (getJsonField(
        response,
        r'''$[:].responsavel.avatar''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => castToType<String>(x))
          .withoutNulls
          .toList();
}

class GetNotificacoesUsuarioCall {
  Future<ApiCallResponse> call({
    String? usuarioId = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'getNotificacoesUsuario',
      apiUrl: '${baseUrl}/notificacoes/${usuarioId}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class UpdateNotificacoesUsuarioCall {
  Future<ApiCallResponse> call({
    List<int>? idsList,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosGroup.getBaseUrl(
      token: token,
    );
    final ids = _serializeList(idsList);

    final ffApiRequestBody = '''
{
  "ids": ${ids}
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'updateNotificacoesUsuario',
      apiUrl: '${baseUrl}/notificacoes/lidas',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

/// End Servidor Jardim Usuarios Group Code

/// Start Servidor Jardim Usuarios Copy Group Code

class ServidorJardimUsuariosCopyGroup {
  static String getBaseUrl({
    String? token = '',
  }) =>
      'http://131.108.242.55:9002';
  static Map<String, String> headers = {
    'Accept': '*/*',
    'Content-Type': 'application/json',
    'Authorization': 'Bearer [token]',
  };
  static UserLoginCopyCall userLoginCopyCall = UserLoginCopyCall();
  static CreateUserCopyCall createUserCopyCall = CreateUserCopyCall();
  static VerifyCodeCopyCall verifyCodeCopyCall = VerifyCodeCopyCall();
  static GetRepresentantesCopyCall getRepresentantesCopyCall =
      GetRepresentantesCopyCall();
  static ResetPasswordCopyCall resetPasswordCopyCall = ResetPasswordCopyCall();
  static ReenviarTokenCopyCall reenviarTokenCopyCall = ReenviarTokenCopyCall();
  static UpdatePasswordCopyCall updatePasswordCopyCall =
      UpdatePasswordCopyCall();
  static RecoveryPasswordCopyCall recoveryPasswordCopyCall =
      RecoveryPasswordCopyCall();
  static AddPasswordToNewUserCopyCall addPasswordToNewUserCopyCall =
      AddPasswordToNewUserCopyCall();
  static AddRepresentanteCopyCall addRepresentanteCopyCall =
      AddRepresentanteCopyCall();
  static GetSolicitacaoImageCopyCall getSolicitacaoImageCopyCall =
      GetSolicitacaoImageCopyCall();
}

class UserLoginCopyCall {
  Future<ApiCallResponse> call({
    String? cpf = '',
    String? senha = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "cpf": "${escapeStringForJson(cpf)}",
  "senha": "${escapeStringForJson(senha)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'UserLogin Copy',
      apiUrl: '${baseUrl}/usuarios/login/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? token(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.access_token''',
      ));
}

class CreateUserCopyCall {
  Future<ApiCallResponse> call({
    String? nomeCompleto = '',
    String? cpf = '',
    String? whatsapp = '',
    String? email = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "nome_completo": "${escapeStringForJson(nomeCompleto)}",
  "cpf": "${escapeStringForJson(cpf)}",
  "whatsapp": "${escapeStringForJson(whatsapp)}",
  "email": "${escapeStringForJson(email)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'CreateUser Copy',
      apiUrl: '${baseUrl}/usuarios/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? detail(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
  CreatedUserStruct? rsult(dynamic response) =>
      CreatedUserStruct.maybeFromMap(getJsonField(
        response,
        r'''$''',
      ));
}

class VerifyCodeCopyCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? codigo = '',
    String? tipo = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_id": ${usuarioId},
  "codigo": "${escapeStringForJson(codigo)}",
  "tipo": "${escapeStringForJson(tipo)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'verifyCode Copy',
      apiUrl: '${baseUrl}/usuarios/verificar/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? mensagem(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.message''',
      ));
  String? erro(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
}

class GetRepresentantesCopyCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'getRepresentantes Copy',
      apiUrl: '${baseUrl}/usuarios/${usuarioId}/representantes/',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  List<RepresentanteStruct>? result(dynamic response) => (getJsonField(
        response,
        r'''$''',
        true,
      ) as List?)
          ?.withoutNulls
          .map((x) => RepresentanteStruct.maybeFromMap(x))
          .withoutNulls
          .toList();
}

class ResetPasswordCopyCall {
  Future<ApiCallResponse> call({
    String? email = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{"email":"${escapeStringForJson(email)}"}''';
    return ApiManager.instance.makeApiCall(
      callName: 'resetPassword Copy',
      apiUrl: '${baseUrl}/usuarios/resetar_senha/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? mensagem(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.message''',
      ));
}

class ReenviarTokenCopyCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? tipo = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_id": "${usuarioId}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'reenviarToken Copy',
      apiUrl: '${baseUrl}/usuarios/reenviar_token/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class UpdatePasswordCopyCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? codigo = '',
    String? novaSenha = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_id": ${usuarioId}
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'updatePassword Copy',
      apiUrl: '${baseUrl}/usuarios/atualizar_senha/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class RecoveryPasswordCopyCall {
  Future<ApiCallResponse> call({
    String? email = '',
    String? cpf = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "cpf": "${escapeStringForJson(cpf)}",
  "email": "${escapeStringForJson(email)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'recoveryPassword Copy',
      apiUrl: '${baseUrl}/usuarios/recuperar_senha/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  UserDataStruct? result(dynamic response) =>
      UserDataStruct.maybeFromMap(getJsonField(
        response,
        r'''$''',
      ));
  String? error(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
}

class AddPasswordToNewUserCopyCall {
  Future<ApiCallResponse> call({
    String? usuarioCpf = '',
    String? senha = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "usuario_cpf": "${escapeStringForJson(usuarioCpf)}",
  "senha": "${escapeStringForJson(senha)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'addPasswordToNewUser Copy',
      apiUrl: '${baseUrl}/usuarios/${usuarioCpf}/senha/',
      callType: ApiCallType.PATCH,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  String? detail(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.detail''',
      ));
}

class AddRepresentanteCopyCall {
  Future<ApiCallResponse> call({
    int? usuarioId,
    String? cpf = '',
    String? nome = '',
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    final ffApiRequestBody = '''
{
  "cpf":"${escapeStringForJson(cpf)}",
  "usuario_id":${usuarioId},
  "nome":"${escapeStringForJson(nome)}"
}''';
    return ApiManager.instance.makeApiCall(
      callName: 'addRepresentante Copy',
      apiUrl: '${baseUrl}/usuarios/${usuarioId}/representantes/',
      callType: ApiCallType.POST,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class GetSolicitacaoImageCopyCall {
  Future<ApiCallResponse> call({
    String? filename = '',
    int? solicitacaoId,
    String? token = '',
  }) async {
    final baseUrl = ServidorJardimUsuariosCopyGroup.getBaseUrl(
      token: token,
    );

    return ApiManager.instance.makeApiCall(
      callName: 'getSolicitacaoImage Copy',
      apiUrl: '${baseUrl}/files/${solicitacaoId}/${filename}/${token}',
      callType: ApiCallType.GET,
      headers: {
        'Accept': '*/*',
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

/// End Servidor Jardim Usuarios Copy Group Code

class LoginCall {
  static Future<ApiCallResponse> call({
    String? usuario = '',
    String? senha = '',
  }) async {
    final ffApiRequestBody = '''
{"clientId":"${escapeStringForJson(usuario)}",
"secret":"${escapeStringForJson(senha)}"}''';
    return ApiManager.instance.makeApiCall(
      callName: 'login',
      apiUrl: 'https://api.navegantes.digital/auth/v1/login',
      callType: ApiCallType.POST,
      headers: {},
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }
}

class GetTokenAvantinoCall {
  static Future<ApiCallResponse> call({
    String? nmLogin = '',
    String? dsSenha = '',
  }) async {
    return ApiManager.instance.makeApiCall(
      callName: 'getTokenAvantino',
      apiUrl: 'https://avantino.pbr.digital/cje/api/login/',
      callType: ApiCallType.GET,
      headers: {},
      params: {
        'nmLogin': nmLogin,
        'dsSenha': dsSenha,
      },
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  static dynamic? result(dynamic response) => getJsonField(
        response,
        r'''$''',
      );
  static String? token(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.token''',
      ));
  static bool? auth(dynamic response) => castToType<bool>(getJsonField(
        response,
        r'''$.auth''',
      ));
}

class BoletoPDFCall {
  static Future<ApiCallResponse> call({
    int? idboleto,
    String? token = '',
  }) async {
    return ApiManager.instance.makeApiCall(
      callName: 'BoletoPDF',
      apiUrl:
          'https://api.navegantes.digital/management/v1/billets/${idboleto}/pdf',
      callType: ApiCallType.GET,
      headers: {
        'Authorization': 'Bearer ${token}',
      },
      params: {},
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: true,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  static String? link(dynamic response) => castToType<String>(getJsonField(
        response,
        r'''$.link''',
      ));
}

class GetTokenAvantinoIICall {
  static Future<ApiCallResponse> call() async {
    final ffApiRequestBody = '''
   {
        "clientId": "cje.wiser",
        "secret": "2j9i197ulHZRxKN7"
    }''';
    return ApiManager.instance.makeApiCall(
      callName: 'getTokenAvantinoII',
      apiUrl: 'https://api.navegantes.digital/auth/v1/login',
      callType: ApiCallType.POST,
      headers: {},
      params: {},
      body: ffApiRequestBody,
      bodyType: BodyType.JSON,
      returnBody: true,
      encodeBodyUtf8: false,
      decodeUtf8: false,
      cache: false,
      isStreamingApi: false,
      alwaysAllowBody: false,
    );
  }

  static String? accesstoken(dynamic response) =>
      castToType<String>(getJsonField(
        response,
        r'''$.access_token''',
      ));
}

class ApiPagingParams {
  int nextPageNumber = 0;
  int numItems = 0;
  dynamic lastResponse;

  ApiPagingParams({
    required this.nextPageNumber,
    required this.numItems,
    required this.lastResponse,
  });

  @override
  String toString() =>
      'PagingParams(nextPageNumber: $nextPageNumber, numItems: $numItems, lastResponse: $lastResponse,)';
}

String _toEncodable(dynamic item) {
  return item;
}

String _serializeList(List? list) {
  list ??= <String>[];
  try {
    return json.encode(list, toEncodable: _toEncodable);
  } catch (_) {
    if (kDebugMode) {
      print("List serialization failed. Returning empty list.");
    }
    return '[]';
  }
}

String _serializeJson(dynamic jsonVar, [bool isList = false]) {
  jsonVar ??= (isList ? [] : {});
  try {
    return json.encode(jsonVar, toEncodable: _toEncodable);
  } catch (_) {
    if (kDebugMode) {
      print("Json serialization failed. Returning empty json.");
    }
    return isList ? '[]' : '{}';
  }
}

String? escapeStringForJson(String? input) {
  if (input == null) {
    return null;
  }
  return input
      .replaceAll('\\', '\\\\')
      .replaceAll('"', '\\"')
      .replaceAll('\n', '\\n')
      .replaceAll('\t', '\\t');
}
