import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/flutter_flow_util.dart';
import 'dart:ui';
import '/flutter_flow/custom_functions.dart' as functions;
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:provider/provider.dart';
import 'plano_card_model.dart';
export 'plano_card_model.dart';

class PlanoCardWidget extends StatefulWidget {
  const PlanoCardWidget({
    super.key,
    required this.nome,
  });

  final String? nome;

  @override
  State<PlanoCardWidget> createState() => _PlanoCardWidgetState();
}

class _PlanoCardWidgetState extends State<PlanoCardWidget> {
  late PlanoCardModel _model;

  @override
  void setState(VoidCallback callback) {
    super.setState(callback);
    _model.onUpdate();
  }

  @override
  void initState() {
    super.initState();
    _model = createModel(context, () => PlanoCardModel());

    WidgetsBinding.instance.addPostFrameCallback((_) => safeSetState(() {}));
  }

  @override
  void dispose() {
    _model.maybeDispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsetsDirectional.fromSTEB(5.0, 12.0, 5.0, 12.0),
      child: InkWell(
        splashColor: Colors.transparent,
        focusColor: Colors.transparent,
        hoverColor: Colors.transparent,
        highlightColor: Colors.transparent,
        onTap: () async {
          context.pushNamed(
            'DetalhePlano',
            queryParameters: {
              'cobertura': serializeParam(
                widget!.nome,
                ParamType.String,
              ),
            }.withoutNulls,
          );
        },
        child: Container(
          width: 500.0,
          decoration: BoxDecoration(
            color: Colors.white,
            boxShadow: [
              BoxShadow(
                blurRadius: 7.0,
                color: Color(0x2F1D2429),
                offset: Offset(
                  0.0,
                  3.0,
                ),
              )
            ],
            borderRadius: BorderRadius.circular(10.0),
          ),
          child: Padding(
            padding: EdgeInsets.all(12.0),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Padding(
                  padding: EdgeInsetsDirectional.fromSTEB(0.0, 8.0, 0.0, 8.0),
                  child: Row(
                    mainAxisSize: MainAxisSize.min,
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Text(
                        valueOrDefault<String>(
                          widget!.nome,
                          'Cobertura',
                        ).maybeHandleOverflow(
                          maxChars: 25,
                        ),
                        textAlign: TextAlign.center,
                        style: FlutterFlowTheme.of(context).bodyLarge.override(
                              fontFamily: 'Plus Jakarta Sans',
                              color: Color(0xFF74838E),
                              fontSize: 22.0,
                              letterSpacing: 0.0,
                              fontWeight: FontWeight.bold,
                            ),
                      ),
                    ],
                  ),
                ),
                if (widget!.nome == 'FNR. ECONOMICO')
                  ClipRRect(
                    borderRadius: BorderRadius.circular(8.0),
                    child: Image.asset(
                      'assets/images/k7eg7_8.png',
                      width: double.infinity,
                      height: 100.0,
                      fit: BoxFit.cover,
                      alignment: Alignment(0.0, -0.5),
                    ),
                  ),
                if (functions.containsString('JAZ. MANUTENCAO', widget!.nome!))
                  ClipRRect(
                    borderRadius: BorderRadius.circular(8.0),
                    child: Image.asset(
                      'assets/images/descanso.jpeg',
                      width: double.infinity,
                      height: 100.0,
                      fit: BoxFit.cover,
                    ),
                  ),
                if (widget!.nome == 'cremacao')
                  ClipRRect(
                    borderRadius: BorderRadius.circular(8.0),
                    child: Image.asset(
                      'assets/images/crematorio-1.jpeg',
                      width: double.infinity,
                      height: 100.0,
                      fit: BoxFit.cover,
                    ),
                  ),
                if (widget!.nome == 'ossuario')
                  ClipRRect(
                    borderRadius: BorderRadius.circular(8.0),
                    child: Image.asset(
                      'assets/images/ossuario.jpg',
                      width: double.infinity,
                      height: 100.0,
                      fit: BoxFit.cover,
                      alignment: Alignment(0.0, -0.3),
                    ),
                  ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
