// Automatic FlutterFlow imports
import '/backend/schema/structs/index.dart';
import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/flutter_flow_util.dart';
import 'index.dart'; // Imports other custom actions
import '/flutter_flow/custom_functions.dart'; // Imports custom functions
import 'package:flutter/material.dart';
// Begin custom action code
// DO NOT REMOVE OR MODIFY THE CODE ABOVE!

import 'dart:typed_data';
import 'package:file_picker/file_picker.dart';

// Função para selecionar e retornar uma lista de arquivos (List<FFUploadedFile>)
Future<List<FFUploadedFile>> documentPicker() async {
  final selectedFiles = await selectFiles(
    allowedExtensions: ['pdf'], // Extensões permitidas
    multiFile: true, // Permitir múltiplos arquivos
  );

  if (selectedFiles.isNotEmpty) {
    // Converter arquivos selecionados para FFUploadedFile
    var selectedUploadedFiles = selectedFiles.map((file) {
      return FFUploadedFile(
        name: file.storagePath,
        bytes: file.bytes,
      );
    }).toList();

    // Atualizar o estado do app com uma lista contendo os nomes de todos os arquivos
    FFAppState().fileNames = selectedUploadedFiles
        .map((uploadedFile) => uploadedFile.name ?? '')
        .where((name) => name.isNotEmpty)
        .toList();

    // Retornar a lista de arquivos
    return selectedUploadedFiles;
  }

  // Retornar lista vazia se nenhum arquivo for selecionado
  return [];
}

// Função auxiliar para selecionar arquivos usando file_picker
Future<List<SelectedFile>> selectFiles({
  List<String>? allowedExtensions,
  bool multiFile = false,
}) async {
  final result = await FilePicker.platform.pickFiles(
    type: allowedExtensions != null ? FileType.custom : FileType.any,
    allowedExtensions: allowedExtensions,
    withData: true,
    allowMultiple: multiFile, // Permitir múltiplos arquivos
  );

  if (result == null || result.files.isEmpty) {
    return [];
  }

  // Mapeia os arquivos para objetos SelectedFile
  return result.files.map((file) {
    return SelectedFile(
      storagePath: file.name,
      filePath: isWeb ? null : file.path,
      bytes: file.bytes!,
    );
  }).toList();
}

// Classe para representar um arquivo selecionado
class SelectedFile {
  const SelectedFile({
    required this.storagePath,
    this.filePath,
    required this.bytes,
    this.dimensions,
    this.blurHash,
  });

  final String storagePath; // Nome ou caminho do arquivo
  final String?
      filePath; // Caminho no sistema de arquivos local (não usado no web)
  final Uint8List bytes; // Bytes do arquivo selecionado
  final MediaDimensions? dimensions; // Dimensões da mídia, se aplicável
  final String? blurHash; // BlurHash, se aplicável
}

// Classe para representar dimensões de mídia (opcional)
class MediaDimensions {
  const MediaDimensions({
    this.height,
    this.width,
  });

  final double? height; // Altura da mídia
  final double? width; // Largura da mídia
}
