import 'dart:async';

import 'package:flutter/material.dart';
import 'package:go_router/go_router.dart';
import 'package:page_transition/page_transition.dart';
import 'package:provider/provider.dart';

import '/backend/schema/structs/index.dart';

import '/index.dart';
import '/main.dart';
import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/lat_lng.dart';
import '/flutter_flow/place.dart';
import '/flutter_flow/flutter_flow_util.dart';
import 'serialization_util.dart';

export 'package:go_router/go_router.dart';
export 'serialization_util.dart';

const kTransitionInfoKey = '__transition_info__';

GlobalKey<NavigatorState> appNavigatorKey = GlobalKey<NavigatorState>();

class AppStateNotifier extends ChangeNotifier {
  AppStateNotifier._();

  static AppStateNotifier? _instance;
  static AppStateNotifier get instance => _instance ??= AppStateNotifier._();

  bool showSplashImage = true;

  void stopShowingSplashImage() {
    showSplashImage = false;
    notifyListeners();
  }
}

GoRouter createRouter(AppStateNotifier appStateNotifier) => GoRouter(
      initialLocation: '/',
      debugLogDiagnostics: true,
      refreshListenable: appStateNotifier,
      navigatorKey: appNavigatorKey,
      errorBuilder: (context, state) => HomeWidget(),
      routes: [
        FFRoute(
          name: '_initialize',
          path: '/',
          builder: (context, _) => HomeWidget(),
        ),
        FFRoute(
          name: 'Home',
          path: '/home',
          builder: (context, params) => HomeWidget(),
        ),
        FFRoute(
          name: 'Login',
          path: '/login',
          builder: (context, params) => LoginWidget(),
        ),
        FFRoute(
          name: 'Cadastro',
          path: '/cadastro',
          builder: (context, params) => CadastroWidget(),
        ),
        FFRoute(
          name: 'ConfirmaCadastro',
          path: '/confirmaCadastro',
          builder: (context, params) => ConfirmaCadastroWidget(),
        ),
        FFRoute(
          name: 'CriarSenha',
          path: '/criarSenha',
          builder: (context, params) => CriarSenhaWidget(),
        ),
        FFRoute(
          name: 'FaleConosco',
          path: '/faleConosco',
          builder: (context, params) => FaleConoscoWidget(),
        ),
        FFRoute(
          name: 'RedefinirSenha',
          path: '/redefinirSenha',
          builder: (context, params) => RedefinirSenhaWidget(),
        ),
        FFRoute(
          name: 'ConfirmarRedefinirSenha',
          path: '/confirmarRedefinirSenha',
          builder: (context, params) => ConfirmarRedefinirSenhaWidget(),
        ),
        FFRoute(
          name: 'SelecionarUsuario',
          path: '/selecionarUsuario',
          builder: (context, params) => SelecionarUsuarioWidget(
            representantes: params.getParam<RepresentanteStruct>(
              'representantes',
              ParamType.DataStruct,
              isList: true,
              structBuilder: RepresentanteStruct.fromSerializableMap,
            ),
          ),
        ),
        FFRoute(
          name: 'PaginaTitular',
          path: '/paginaTitular',
          builder: (context, params) => PaginaTitularWidget(
            cpf: params.getParam(
              'cpf',
              ParamType.String,
            ),
            nomeusuario: params.getParam(
              'nomeusuario',
              ParamType.String,
            ),
          ),
        ),
        FFRoute(
          name: 'Boletos',
          path: '/boletos',
          builder: (context, params) => BoletosWidget(
            contrato: params.getParam(
              'contrato',
              ParamType.int,
            ),
          ),
        ),
        FFRoute(
          name: 'PagarItem',
          path: '/pagarItem',
          builder: (context, params) => PagarItemWidget(
            boleto: params.getParam(
              'boleto',
              ParamType.DataStruct,
              isList: false,
              structBuilder: FaturaStruct.fromSerializableMap,
            ),
            faturas: params.getParam<FaturaStruct>(
              'faturas',
              ParamType.DataStruct,
              isList: true,
              structBuilder: FaturaStruct.fromSerializableMap,
            ),
          ),
        ),
        FFRoute(
          name: 'Jazigos',
          path: '/Jazigos',
          builder: (context, params) => JazigosWidget(),
        ),
        FFRoute(
          name: 'MeusPlanos',
          path: '/meusPlanos',
          builder: (context, params) => MeusPlanosWidget(
            contratos: params.getParam<ContratoStruct>(
              'contratos',
              ParamType.DataStruct,
              isList: true,
              structBuilder: ContratoStruct.fromSerializableMap,
            ),
          ),
        ),
        FFRoute(
          name: 'DetalhePlano',
          path: '/detalhePlano',
          builder: (context, params) => DetalhePlanoWidget(
            cobertura: params.getParam(
              'cobertura',
              ParamType.String,
            ),
          ),
        ),
        FFRoute(
          name: 'MelhorarPlano',
          path: '/melhorarPlano',
          builder: (context, params) => MelhorarPlanoWidget(),
        ),
        FFRoute(
          name: 'DadosPessoais',
          path: '/dadosPessoais',
          builder: (context, params) => DadosPessoaisWidget(),
        ),
        FFRoute(
          name: 'Dependentes',
          path: '/dependentes',
          builder: (context, params) => DependentesWidget(
            solicitacaoid: params.getParam(
              'solicitacaoid',
              ParamType.int,
            ),
            tipoid: params.getParam(
              'tipoid',
              ParamType.int,
            ),
          ),
        ),
        FFRoute(
          name: 'AlterarDependente',
          path: '/alterarDependente',
          builder: (context, params) => AlterarDependenteWidget(
            nomecompleto: params.getParam(
              'nomecompleto',
              ParamType.String,
            ),
            grauparentescoeditar: params.getParam(
              'grauparentescoeditar',
              ParamType.String,
            ),
            datanascimentoeditar: params.getParam(
              'datanascimentoeditar',
              ParamType.String,
            ),
            cpfeditar: params.getParam(
              'cpfeditar',
              ParamType.String,
            ),
            ideditar: params.getParam(
              'ideditar',
              ParamType.String,
            ),
          ),
        ),
        FFRoute(
          name: 'IncluirDependente',
          path: '/incluirDependente',
          builder: (context, params) => IncluirDependenteWidget(
            nomecompleto: params.getParam(
              'nomecompleto',
              ParamType.String,
            ),
            grauparentescoeditar: params.getParam(
              'grauparentescoeditar',
              ParamType.String,
            ),
            datanascimentoeditar: params.getParam(
              'datanascimentoeditar',
              ParamType.String,
            ),
            cpfeditar: params.getParam(
              'cpfeditar',
              ParamType.String,
            ),
            ideditar: params.getParam(
              'ideditar',
              ParamType.String,
            ),
          ),
        ),
        FFRoute(
          name: 'HistoricoSolicitacoes',
          path: '/historicoSolicitacoes',
          builder: (context, params) => HistoricoSolicitacoesWidget(),
        ),
        FFRoute(
          name: 'AdicionarRepresentante',
          path: '/adicionarRepresentante',
          builder: (context, params) => AdicionarRepresentanteWidget(),
        ),
        FFRoute(
          name: 'HistoricoDetalhes',
          path: '/historicoDetalhes',
          builder: (context, params) => HistoricoDetalhesWidget(
            tiposolicitacao: params.getParam(
              'tiposolicitacao',
              ParamType.String,
            ),
            datahorasolicitacao: params.getParam(
              'datahorasolicitacao',
              ParamType.String,
            ),
            statussolicitacao: params.getParam(
              'statussolicitacao',
              ParamType.String,
            ),
            atendentesolicitacao: params.getParam(
              'atendentesolicitacao',
              ParamType.int,
            ),
            observacaosolicitacao: params.getParam(
              'observacaosolicitacao',
              ParamType.String,
            ),
            idsolicitacao: params.getParam(
              'idsolicitacao',
              ParamType.int,
            ),
            nomeatendentesolicitacao: params.getParam(
              'nomeatendentesolicitacao',
              ParamType.String,
            ),
            avataratendentesolicitacao: params.getParam(
              'avataratendentesolicitacao',
              ParamType.String,
            ),
          ),
        ),
        FFRoute(
          name: 'AlterarDependenteSolicitacao',
          path: '/alterarDependenteSolicitacao',
          builder: (context, params) => AlterarDependenteSolicitacaoWidget(
            nomecompleto: params.getParam(
              'nomecompleto',
              ParamType.String,
            ),
            grauparentescoeditar: params.getParam(
              'grauparentescoeditar',
              ParamType.String,
            ),
            datanascimentoeditar: params.getParam(
              'datanascimentoeditar',
              ParamType.String,
            ),
            cpfeditar: params.getParam(
              'cpfeditar',
              ParamType.String,
            ),
            ideditar: params.getParam(
              'ideditar',
              ParamType.String,
            ),
            solicitacaoid: params.getParam(
              'solicitacaoid',
              ParamType.int,
            ),
          ),
        ),
        FFRoute(
          name: 'IncluirDependenteSolicitacao',
          path: '/incluirDependenteSolicitacao',
          builder: (context, params) => IncluirDependenteSolicitacaoWidget(
            nomecompleto: params.getParam(
              'nomecompleto',
              ParamType.String,
            ),
            grauparentescoeditar: params.getParam(
              'grauparentescoeditar',
              ParamType.String,
            ),
            datanascimentoeditar: params.getParam(
              'datanascimentoeditar',
              ParamType.String,
            ),
            cpfeditar: params.getParam(
              'cpfeditar',
              ParamType.String,
            ),
            ideditar: params.getParam(
              'ideditar',
              ParamType.String,
            ),
            solicitacaoid: params.getParam(
              'solicitacaoid',
              ParamType.int,
            ),
          ),
        ),
        FFRoute(
          name: 'DadosPessoaisSolicitacao',
          path: '/dadosPessoaisSolicitacao',
          builder: (context, params) => DadosPessoaisSolicitacaoWidget(
            tipoid: params.getParam(
              'tipoid',
              ParamType.int,
            ),
            solicitacaoid: params.getParam(
              'solicitacaoid',
              ParamType.int,
            ),
          ),
        ),
        FFRoute(
          name: 'LinhaDigitavel',
          path: '/linhaDigitavel',
          builder: (context, params) => LinhaDigitavelWidget(
            boleto: params.getParam(
              'boleto',
              ParamType.DataStruct,
              isList: false,
              structBuilder: FaturaStruct.fromSerializableMap,
            ),
            faturas: params.getParam<FaturaStruct>(
              'faturas',
              ParamType.DataStruct,
              isList: true,
              structBuilder: FaturaStruct.fromSerializableMap,
            ),
          ),
        )
      ].map((r) => r.toRoute(appStateNotifier)).toList(),
    );

extension NavParamExtensions on Map<String, String?> {
  Map<String, String> get withoutNulls => Map.fromEntries(
        entries
            .where((e) => e.value != null)
            .map((e) => MapEntry(e.key, e.value!)),
      );
}

extension NavigationExtensions on BuildContext {
  void safePop() {
    // If there is only one route on the stack, navigate to the initial
    // page instead of popping.
    if (canPop()) {
      pop();
    } else {
      go('/');
    }
  }
}

extension _GoRouterStateExtensions on GoRouterState {
  Map<String, dynamic> get extraMap =>
      extra != null ? extra as Map<String, dynamic> : {};
  Map<String, dynamic> get allParams => <String, dynamic>{}
    ..addAll(pathParameters)
    ..addAll(uri.queryParameters)
    ..addAll(extraMap);
  TransitionInfo get transitionInfo => extraMap.containsKey(kTransitionInfoKey)
      ? extraMap[kTransitionInfoKey] as TransitionInfo
      : TransitionInfo.appDefault();
}

class FFParameters {
  FFParameters(this.state, [this.asyncParams = const {}]);

  final GoRouterState state;
  final Map<String, Future<dynamic> Function(String)> asyncParams;

  Map<String, dynamic> futureParamValues = {};

  // Parameters are empty if the params map is empty or if the only parameter
  // present is the special extra parameter reserved for the transition info.
  bool get isEmpty =>
      state.allParams.isEmpty ||
      (state.allParams.length == 1 &&
          state.extraMap.containsKey(kTransitionInfoKey));
  bool isAsyncParam(MapEntry<String, dynamic> param) =>
      asyncParams.containsKey(param.key) && param.value is String;
  bool get hasFutures => state.allParams.entries.any(isAsyncParam);
  Future<bool> completeFutures() => Future.wait(
        state.allParams.entries.where(isAsyncParam).map(
          (param) async {
            final doc = await asyncParams[param.key]!(param.value)
                .onError((_, __) => null);
            if (doc != null) {
              futureParamValues[param.key] = doc;
              return true;
            }
            return false;
          },
        ),
      ).onError((_, __) => [false]).then((v) => v.every((e) => e));

  dynamic getParam<T>(
    String paramName,
    ParamType type, {
    bool isList = false,
    StructBuilder<T>? structBuilder,
  }) {
    if (futureParamValues.containsKey(paramName)) {
      return futureParamValues[paramName];
    }
    if (!state.allParams.containsKey(paramName)) {
      return null;
    }
    final param = state.allParams[paramName];
    // Got parameter from `extras`, so just directly return it.
    if (param is! String) {
      return param;
    }
    // Return serialized value.
    return deserializeParam<T>(
      param,
      type,
      isList,
      structBuilder: structBuilder,
    );
  }
}

class FFRoute {
  const FFRoute({
    required this.name,
    required this.path,
    required this.builder,
    this.requireAuth = false,
    this.asyncParams = const {},
    this.routes = const [],
  });

  final String name;
  final String path;
  final bool requireAuth;
  final Map<String, Future<dynamic> Function(String)> asyncParams;
  final Widget Function(BuildContext, FFParameters) builder;
  final List<GoRoute> routes;

  GoRoute toRoute(AppStateNotifier appStateNotifier) => GoRoute(
        name: name,
        path: path,
        pageBuilder: (context, state) {
          fixStatusBarOniOS16AndBelow(context);
          final ffParams = FFParameters(state, asyncParams);
          final page = ffParams.hasFutures
              ? FutureBuilder(
                  future: ffParams.completeFutures(),
                  builder: (context, _) => builder(context, ffParams),
                )
              : builder(context, ffParams);
          final child = page;

          final transitionInfo = state.transitionInfo;
          return transitionInfo.hasTransition
              ? CustomTransitionPage(
                  key: state.pageKey,
                  child: child,
                  transitionDuration: transitionInfo.duration,
                  transitionsBuilder:
                      (context, animation, secondaryAnimation, child) =>
                          PageTransition(
                    type: transitionInfo.transitionType,
                    duration: transitionInfo.duration,
                    reverseDuration: transitionInfo.duration,
                    alignment: transitionInfo.alignment,
                    child: child,
                  ).buildTransitions(
                    context,
                    animation,
                    secondaryAnimation,
                    child,
                  ),
                )
              : MaterialPage(key: state.pageKey, child: child);
        },
        routes: routes,
      );
}

class TransitionInfo {
  const TransitionInfo({
    required this.hasTransition,
    this.transitionType = PageTransitionType.fade,
    this.duration = const Duration(milliseconds: 300),
    this.alignment,
  });

  final bool hasTransition;
  final PageTransitionType transitionType;
  final Duration duration;
  final Alignment? alignment;

  static TransitionInfo appDefault() => TransitionInfo(hasTransition: false);
}

class RootPageContext {
  const RootPageContext(this.isRootPage, [this.errorRoute]);
  final bool isRootPage;
  final String? errorRoute;

  static bool isInactiveRootPage(BuildContext context) {
    final rootPageContext = context.read<RootPageContext?>();
    final isRootPage = rootPageContext?.isRootPage ?? false;
    final location = GoRouterState.of(context).uri.toString();
    return isRootPage &&
        location != '/' &&
        location != rootPageContext?.errorRoute;
  }

  static Widget wrap(Widget child, {String? errorRoute}) => Provider.value(
        value: RootPageContext(true, errorRoute),
        child: child,
      );
}

extension GoRouterLocationExtension on GoRouter {
  String getCurrentLocation() {
    final RouteMatch lastMatch = routerDelegate.currentConfiguration.last;
    final RouteMatchList matchList = lastMatch is ImperativeRouteMatch
        ? lastMatch.matches
        : routerDelegate.currentConfiguration;
    return matchList.uri.toString();
  }
}
