import '/backend/api_requests/api_calls.dart';
import '/backend/schema/structs/index.dart';
import '/components/pagamento_listar_item_widget.dart';
import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/flutter_flow_util.dart';
import '/flutter_flow/flutter_flow_widgets.dart';
import 'dart:ui';
import '/flutter_flow/custom_functions.dart' as functions;
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:provider/provider.dart';
import 'boletos_model.dart';
export 'boletos_model.dart';

class BoletosWidget extends StatefulWidget {
  const BoletosWidget({
    super.key,
    required this.contrato,
  });

  final int? contrato;

  @override
  State<BoletosWidget> createState() => _BoletosWidgetState();
}

class _BoletosWidgetState extends State<BoletosWidget> {
  late BoletosModel _model;

  final scaffoldKey = GlobalKey<ScaffoldState>();

  @override
  void initState() {
    super.initState();
    _model = createModel(context, () => BoletosModel());

    WidgetsBinding.instance.addPostFrameCallback((_) => safeSetState(() {}));
  }

  @override
  void dispose() {
    _model.dispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    context.watch<FFAppState>();

    return Title(
        title: 'Boletos',
        color: FlutterFlowTheme.of(context).primary.withAlpha(0XFF),
        child: GestureDetector(
          onTap: () {
            FocusScope.of(context).unfocus();
            FocusManager.instance.primaryFocus?.unfocus();
          },
          child: Scaffold(
            key: scaffoldKey,
            backgroundColor: FlutterFlowTheme.of(context).primaryBackground,
            body: SafeArea(
              top: true,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  Text(
                    'Boletos',
                    style: FlutterFlowTheme.of(context).bodyMedium.override(
                          fontFamily: 'Inter',
                          fontSize: 24.0,
                          letterSpacing: 0.0,
                          fontWeight: FontWeight.w800,
                        ),
                  ),
                  Padding(
                    padding:
                        EdgeInsetsDirectional.fromSTEB(5.0, 15.0, 5.0, 0.0),
                    child: Row(
                      mainAxisSize: MainAxisSize.max,
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        if (FFAppState().composicaoselecionado == true)
                          Expanded(
                            child: Padding(
                              padding: EdgeInsetsDirectional.fromSTEB(
                                  15.0, 0.0, 15.0, 0.0),
                              child: FFButtonWidget(
                                onPressed: () {
                                  print('Button pressed ...');
                                },
                                text: 'Composição de pagamentos',
                                icon: Icon(
                                  Icons.paid,
                                  size: 20.0,
                                ),
                                options: FFButtonOptions(
                                  height: 40.0,
                                  padding: EdgeInsetsDirectional.fromSTEB(
                                      16.0, 0.0, 16.0, 0.0),
                                  iconPadding: EdgeInsetsDirectional.fromSTEB(
                                      0.0, 0.0, 0.0, 0.0),
                                  color: Color(0xFFF2BB68),
                                  textStyle: FlutterFlowTheme.of(context)
                                      .titleSmall
                                      .override(
                                        fontFamily: 'Montserrat',
                                        color: FlutterFlowTheme.of(context)
                                            .primaryText,
                                        letterSpacing: 0.0,
                                      ),
                                  elevation: 0.0,
                                  borderRadius: BorderRadius.circular(20.0),
                                ),
                              ),
                            ),
                          ),
                      ],
                    ),
                  ),
                  Padding(
                    padding:
                        EdgeInsetsDirectional.fromSTEB(0.0, 20.0, 0.0, 0.0),
                    child: Container(
                      width: double.infinity,
                      height: 670.0,
                      decoration: BoxDecoration(
                        color: Color(0xFFF1F4F8),
                      ),
                      child: Padding(
                        padding:
                            EdgeInsetsDirectional.fromSTEB(5.0, 0.0, 5.0, 0.0),
                        child: FutureBuilder<ApiCallResponse>(
                          future:
                              GrupoAPIAvantinoIGroup.faturasByContratoCall.call(
                            idContrato: widget!.contrato,
                            token: FFAppState().avantToken,
                          ),
                          builder: (context, snapshot) {
                            // Customize what your widget looks like when it's loading.
                            if (!snapshot.hasData) {
                              return Center(
                                child: SizedBox(
                                  width: 50.0,
                                  height: 50.0,
                                  child: CircularProgressIndicator(
                                    valueColor: AlwaysStoppedAnimation<Color>(
                                      FlutterFlowTheme.of(context).primary,
                                    ),
                                  ),
                                ),
                              );
                            }
                            final listViewFaturasByContratoResponse =
                                snapshot.data!;

                            return Builder(
                              builder: (context) {
                                final boleto = GrupoAPIAvantinoIGroup
                                        .faturasByContratoCall
                                        .resukt(
                                          listViewFaturasByContratoResponse
                                              .jsonBody,
                                        )
                                        ?.where((e) =>
                                            dateTimeFormat(
                                              "y",
                                              functions.stringToDateTime(
                                                  e.dtVencimento),
                                              locale:
                                                  FFLocalizations.of(context)
                                                      .languageCode,
                                            ) ==
                                            dateTimeFormat(
                                              "y",
                                              getCurrentTimestamp,
                                              locale:
                                                  FFLocalizations.of(context)
                                                      .languageCode,
                                            ))
                                        .toList()
                                        ?.sortedList(
                                            keyOf: (e) =>
                                                functions.stringToDateTime(
                                                    e.dtVencimento),
                                            desc: false)
                                        ?.toList() ??
                                    [];

                                return ListView.separated(
                                  padding: EdgeInsets.zero,
                                  shrinkWrap: true,
                                  scrollDirection: Axis.vertical,
                                  itemCount: boleto.length,
                                  separatorBuilder: (_, __) =>
                                      SizedBox(height: 5.0),
                                  itemBuilder: (context, boletoIndex) {
                                    final boletoItem = boleto[boletoIndex];
                                    return wrapWithModel(
                                      model: _model.pagamentoListarItemModels
                                          .getModel(
                                        boletoItem.idBoleto,
                                        boletoIndex,
                                      ),
                                      updateCallback: () => safeSetState(() {}),
                                      child: PagamentoListarItemWidget(
                                        key: Key(
                                          'Keyrw4_${boletoItem.idBoleto}',
                                        ),
                                        boleto: boletoItem,
                                        faturas: GrupoAPIAvantinoIGroup
                                            .faturasByContratoCall
                                            .resukt(
                                          listViewFaturasByContratoResponse
                                              .jsonBody,
                                        )!,
                                      ),
                                    );
                                  },
                                );
                              },
                            );
                          },
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ));
  }
}
