import '/backend/api_requests/api_calls.dart';
import '/backend/schema/structs/index.dart';
import '/components/jazigos_card_widget.dart';
import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/flutter_flow_util.dart';
import '/flutter_flow/flutter_flow_widgets.dart';
import 'dart:ui';
import '/flutter_flow/custom_functions.dart' as functions;
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:provider/provider.dart';
import 'jazigos_model.dart';
export 'jazigos_model.dart';

class JazigosWidget extends StatefulWidget {
  const JazigosWidget({super.key});

  @override
  State<JazigosWidget> createState() => _JazigosWidgetState();
}

class _JazigosWidgetState extends State<JazigosWidget> {
  late JazigosModel _model;

  final scaffoldKey = GlobalKey<ScaffoldState>();

  @override
  void initState() {
    super.initState();
    _model = createModel(context, () => JazigosModel());

    WidgetsBinding.instance.addPostFrameCallback((_) => safeSetState(() {}));
  }

  @override
  void dispose() {
    _model.dispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    context.watch<FFAppState>();

    return Title(
        title: 'Jazigos',
        color: FlutterFlowTheme.of(context).primary.withAlpha(0XFF),
        child: GestureDetector(
          onTap: () {
            FocusScope.of(context).unfocus();
            FocusManager.instance.primaryFocus?.unfocus();
          },
          child: Scaffold(
            key: scaffoldKey,
            backgroundColor: Color(0xFFF7F5F6),
            body: SafeArea(
              top: true,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  Text(
                    'Jazigos',
                    style: FlutterFlowTheme.of(context).bodyMedium.override(
                          fontFamily: 'Inter',
                          fontSize: 24.0,
                          letterSpacing: 0.0,
                          fontWeight: FontWeight.w800,
                        ),
                  ),
                  if (FFAppState().latitudelongitudeexiste == true)
                    Padding(
                      padding:
                          EdgeInsetsDirectional.fromSTEB(5.0, 15.0, 5.0, 0.0),
                      child: Row(
                        mainAxisSize: MainAxisSize.max,
                        children: [
                          Expanded(
                            child: Padding(
                              padding: EdgeInsetsDirectional.fromSTEB(
                                  15.0, 0.0, 15.0, 0.0),
                              child: FFButtonWidget(
                                onPressed: () {
                                  print('Button pressed ...');
                                },
                                text: 'Como chegar ao Jardim do Éden',
                                icon: Icon(
                                  Icons.map_rounded,
                                  size: 20.0,
                                ),
                                options: FFButtonOptions(
                                  height: 40.0,
                                  padding: EdgeInsetsDirectional.fromSTEB(
                                      16.0, 0.0, 16.0, 0.0),
                                  iconPadding: EdgeInsetsDirectional.fromSTEB(
                                      0.0, 0.0, 0.0, 0.0),
                                  color: Color(0xFFF2BB68),
                                  textStyle: FlutterFlowTheme.of(context)
                                      .titleSmall
                                      .override(
                                        fontFamily: 'Montserrat',
                                        color: FlutterFlowTheme.of(context)
                                            .primaryText,
                                        letterSpacing: 0.0,
                                      ),
                                  elevation: 0.0,
                                  borderRadius: BorderRadius.circular(20.0),
                                ),
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                  Expanded(
                    child: Padding(
                      padding:
                          EdgeInsetsDirectional.fromSTEB(0.0, 20.0, 0.0, 0.0),
                      child: Container(
                        width: double.infinity,
                        decoration: BoxDecoration(
                          color: Color(0xFFF7F5F6),
                        ),
                        child: Padding(
                          padding: EdgeInsetsDirectional.fromSTEB(
                              5.0, 0.0, 5.0, 0.0),
                          child: FutureBuilder<ApiCallResponse>(
                            future: GrupoAPIAvantinoIGroup
                                .financeiroConsultasParametrizadasCall
                                .call(
                              token: FFAppState().avantToken,
                              dominio: 'cje',
                              idContrato: FFAppState().idselecionado,
                            ),
                            builder: (context, snapshot) {
                              // Customize what your widget looks like when it's loading.
                              if (!snapshot.hasData) {
                                return Center(
                                  child: SizedBox(
                                    width: 50.0,
                                    height: 50.0,
                                    child: CircularProgressIndicator(
                                      valueColor: AlwaysStoppedAnimation<Color>(
                                        FlutterFlowTheme.of(context).primary,
                                      ),
                                    ),
                                  ),
                                );
                              }
                              final listViewFinanceiroConsultasParametrizadasResponse =
                                  snapshot.data!;

                              return Builder(
                                builder: (context) {
                                  final jazigoslista = GrupoAPIAvantinoIGroup
                                          .financeiroConsultasParametrizadasCall
                                          .result(
                                            listViewFinanceiroConsultasParametrizadasResponse
                                                .jsonBody,
                                          )
                                          ?.toList() ??
                                      [];

                                  return ListView.separated(
                                    padding: EdgeInsets.zero,
                                    primary: false,
                                    shrinkWrap: true,
                                    scrollDirection: Axis.vertical,
                                    itemCount: jazigoslista.length,
                                    separatorBuilder: (_, __) =>
                                        SizedBox(height: 5.0),
                                    itemBuilder: (context, jazigoslistaIndex) {
                                      final jazigoslistaItem =
                                          jazigoslista[jazigoslistaIndex];
                                      return wrapWithModel(
                                        model:
                                            _model.jazigosCardModels.getModel(
                                          jazigoslistaIndex.toString(),
                                          jazigoslistaIndex,
                                        ),
                                        updateCallback: () =>
                                            safeSetState(() {}),
                                        child: JazigosCardWidget(
                                          key: Key(
                                            'Key9zd_${jazigoslistaIndex.toString()}',
                                          ),
                                          nomeD: valueOrDefault<String>(
                                            jazigoslistaItem.nmAssentado,
                                            'Não informado',
                                          ),
                                          generoD: valueOrDefault<String>(
                                            jazigoslistaItem.sexo,
                                            'Não informado',
                                          ),
                                          religiaoD: valueOrDefault<String>(
                                            jazigoslistaItem.cdReligiao,
                                            'Não informado',
                                          ),
                                          estadocivilD: valueOrDefault<String>(
                                            jazigoslistaItem.cdEstadoCivil,
                                            'Não informado',
                                          ),
                                          nascimentoD: valueOrDefault<String>(
                                            functions.formatDateTimeToDate(
                                                valueOrDefault<String>(
                                              jazigoslistaItem.dtNascimento,
                                              'Não informado',
                                            )),
                                            'Não informado',
                                          ),
                                          obito: valueOrDefault<String>(
                                            functions.formatDateTimeToDate(
                                                '${jazigoslistaItem.dtObito} - ${jazigoslistaItem.hrObito}'),
                                            'Não informado',
                                          ),
                                          sepultamentoD: valueOrDefault<String>(
                                            functions.formatDateTimeToDate(
                                                '${jazigoslistaItem.dtSepultamento} - ${jazigoslistaItem.hrSepultamento}'),
                                            'Não informado',
                                          ),
                                          assentamentoD:
                                              jazigoslistaItem.idAssentamento,
                                          tipoloculoD: valueOrDefault<String>(
                                            jazigoslistaItem.nmTipoLoculo,
                                            'Não informado',
                                          ),
                                          codigoloculoD: valueOrDefault<String>(
                                            jazigoslistaItem.cdLoculo,
                                            'Não informado',
                                          ),
                                        ),
                                      );
                                    },
                                  );
                                },
                              );
                            },
                          ),
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ));
  }
}
